==> fbg-7.x-1.0.tar.gz: fbg/page.tpl.php <==
	<div id="header">
	  <div class="g1">
        <?php
        // Prepare header
        $site_fields = array();
        if ($site_name) {
        $site_fields[] = check_plain($site_name);
        }
        $site_title = implode(' ', $site_fields);
        if ($site_fields) {
        $site_fields[0] = '<span>'. $site_fields[0] .'</span>';
        }
        $site_html = implode(' ', $site_fields);
        if ($logo || $site_title) {
        print '<h1><a href="'. check_url($front_page) .'" title="'. $site_title .'">';
        if ($logo) {
        print '<img src="'. check_url($logo) .'" alt="'. $site_title .'" id="logo" />';
        }
        print $site_html .'</a></h1>';
	    }
        ?>
      </div>
	  <?php if ($site_slogan): ?>
	    <div class="g2">
		  <h2 id="site_slogan"><?php print $site_slogan ?></h2>
		</div>
	  <?php endif; ?>
	  <?php if ($page['highlighted']): ?>
	    <div id="mission" class="g2">
		  <?php print render($page['highlighted']); ?>
	    </div>
      <?php endif; ?>
	  <?php if ($page['branding']): ?>
		<div class="g2">
		  <?php print render($page['branding']); ?>
	    </div>
	  <?php endif; ?>
	</div>
	<div class="cf"></div>
	<div id="content">
	  <?php if ($page['col1']): ?>
	    <div class="g1">
	      <?php print render($page['col1']); ?>
		</div>
	  <?php endif; ?>
	  <?php if ($page['col2']): ?>
	    <div class="g1">
		  <?php print render($page['col2']); ?>
		</div>
	  <?php endif; ?>
	  <?php if ($page['col3']): ?>
		<div class="g1">
		  <?php print render($page['col3']); ?>
		</div>
	  <?php endif; ?>
	  <?php if ($page['highlighted_2']): ?>
		<div class="g1">
		  <?php print render($page['highlighted_2']); ?>
		</div>
	  <?php endif; ?>
	  <?php if ($page['content_top']): ?>
		<div class="g3">
		  <?php print render($page['content_top']); ?>
		</div>
	  <?php endif; ?>
		<div class="g3">
          <?php print $breadcrumb; ?>
          <?php if ($tabs): print '<div id="tabs-wrapper" class="clearfix">'; endif; ?>
          <?php print render($title_prefix); ?>
          <?php if ($title): print '<h2'. ($tabs ? ' class="with-tabs"' : '') .'>'. $title .'</h2>'; endif; ?>
          <?php print render($title_suffix); ?>
          <?php if ($tabs): print '<ul class="tabs primary">'. render($tabs) .'</ul></div>'; endif; ?>
          <?php if (!empty($tabs2)): echo '<ul class="tabs secondary">'. $tabs2 .'</ul>'; endif; ?>
          <?php if ($show_messages && $messages): print $messages; endif; ?>
          <?php print render($help); ?>
          <?php if ($action_links): ?><ul class="action-links"><?php print render($action_links); ?></ul><?php endif; ?>
          <div class="clearfix">
            <?php print render($page['content']); ?>
          </div>
          <?php print render($page['$feed_icons']); ?>		
		</div>
	  <?php if ($page['content_bottom']): ?>
		<div class="g3">
		  <?php print render($page['content_bottom']); ?>
		</div>
	  <?php endif; ?>
	</div>
	<?php if ($page['footer_message']): ?>
	  <div id="footer" class="g3 cf">
	    <?php print print render($page['footer_message']); ?>
	  </div>
    <?php endif; ?>

==> fbg-7.x-2.0.tar.gz: fbg/page.tpl.php <==
	<div id="header">
	  <?php if ($page['header']): ?>
		<div class="g3">
		  <?php print render($page['header']); ?>
	    </div>
	  <?php endif; ?>
	  <div class="g3">
        <?php
        // Prepare header
        $site_fields = array();
        if ($site_name) {
        $site_fields[] = check_plain($site_name);
        }
        $site_title = implode(' ', $site_fields);
        if ($site_fields) {
        $site_fields[0] = '<span>'. $site_fields[0] .'</span>';
        }
        $site_html = implode(' ', $site_fields);
        if ($logo || $site_title) {
        print '<h1><a href="'. check_url($front_page) .'" title="'. $site_title .'">';
        if ($logo) {
        print '<img src="'. check_url($logo) .'" alt="'. $site_title .'" id="logo" />';
        }
        print $site_html .'</a></h1>';
	    }
        ?>
      </div>
	  <?php if ($site_slogan): ?>
	    <div class="g3">
		  <h2 id="site_slogan"><?php print $site_slogan ?></h2>
		</div>
	  <?php endif; ?>
	  <?php if ($page['highlighted']): ?>
	    <div id="mission" class="g2">
		  <?php print render($page['highlighted']); ?>
	    </div>
      <?php endif; ?>
	  <?php if ($page['branding']): ?>
		<div class="g1">
		  <?php print render($page['branding']); ?>
	    </div>
	  <?php endif; ?>
	</div>
	<div class="cf"></div>
	<?php if ($page['tryptych_top1']): ?>
	  <div class="g1">
	    <?php print render($page['tryptych_top1']); ?>
	  </div>
	<?php endif; ?>
	<?php if ($page['tryptych_top2']): ?>
	  <div class="g1">
	    <?php print render($page['tryptych_top2']); ?>
	  </div>
	<?php endif; ?>
	<?php if ($page['tryptych_top3']): ?>
	  <div class="g1">
		<?php print render($page['tryptych_top3']); ?>
	  </div>
	<?php endif; ?>
	<div class="cf"></div>
	<?php if ($page['highlighted_2']): ?>
	  <div class="g2">
		<?php print render($page['highlighted_2']); ?>
	  </div>
	<?php endif; ?>
	<?php if ($page['branding2']): ?>
	  <div class="g1">
	    <?php print render($page['branding2']); ?>
	  </div>
	<?php endif; ?>
	<?php if ($page['sidebar_first']): ?>
	  <div id="sidebar1" class="g1">
	    <?php print render($page['sidebar_first']); ?>
	  </div>
	<?php endif; ?>
	<div id="content" <?php if ($page['sidebar_first'] xor $page['sidebar_second']): ?>class="g2"<?php endif; ?> <?php if ($page['sidebar_first'] && $page['sidebar_second']): ?>class="g1"<?php endif; ?>>
	  <?php if ($page['content_top']): ?>
		<div class="g3">
		  <?php print render($page['content_top']); ?>
		</div>
	  <?php endif; ?>
		<div class="g3">
          <?php print $breadcrumb; ?>
          <?php if ($tabs): print '<div id="tabs-wrapper" class="clearfix">'; endif; ?>
          <?php print render($title_prefix); ?>
          <?php if ($title): print '<h2'. ($tabs ? ' class="with-tabs"' : '') .'>'. $title .'</h2>'; endif; ?>
          <?php print render($title_suffix); ?>
          <?php if ($tabs): print '<ul class="tabs primary">'. render($tabs) .'</ul></div>'; endif; ?>
          <?php if (!empty($tabs2)): echo '<ul class="tabs secondary">'. $tabs2 .'</ul>'; endif; ?>
          <?php if ($show_messages && $messages): print $messages; endif; ?>
          <?php print render($help); ?>
          <?php if ($action_links): ?><ul class="action-links"><?php print render($action_links); ?></ul><?php endif; ?>
          <div class="clearfix">
            <?php print render($page['content']); ?>
          </div>
          <?php print render($page['$feed_icons']); ?>		
		</div>
	  <?php if ($page['content_bottom']): ?>
		<div class="g3">
		  <?php print render($page['content_bottom']); ?>
		</div>
	  <?php endif; ?>  
	</div>
	<?php if ($page['sidebar_second']): ?>
	  <div id="sidebar2" class="g1">
	    <?php print render($page['sidebar_second']); ?>
	  </div>
	<?php endif; ?>
	<div class="cf"></div>
	<?php if ($page['tryptych_bottom1']): ?>
	  <div class="g1">
	    <?php print render($page['tryptych_bottom1']); ?>
	  </div>
	<?php endif; ?>
	<?php if ($page['tryptych_bottom2']): ?>
	  <div class="g1">
	    <?php print render($page['tryptych_bottom2']); ?>
	  </div>
	<?php endif; ?>
	<?php if ($page['tryptych_bottom3']): ?>
	  <div class="g1">
		<?php print render($page['tryptych_bottom3']); ?>
	  </div>
	<?php endif; ?>
	<?php if ($page['footer']): ?>
	  <div class="g3">
	    <?php print render($page['footer']); ?>
	  </div>
	<?php endif; ?>
	<?php if ($page['footer_message']): ?>
	  <div id="footer" class="g3 cf">
	    <?php print render($page['footer_message']); ?>
	  </div>
    <?php endif; ?>
